@@ -38,63 +38,63 @@ class ResourcesType extends JTable
 {
 	/**
 	 * int(11) Primary key
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $id       		= NULL;
 
 	/**
 	 * varchar(100)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $alias	  		= NULL;
 
 	/**
 	 * varchar(250)
-	 *
+	 * 
 	 * @var string
 	 */
 	var $type     		= NULL;
 
 	/**
 	 * int(11)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $category		= NULL;
 
 	/**
 	 * text
-	 *
+	 * 
 	 * @var string
 	 */
 	var $description 	= NULL;
 
 	/**
 	 * int(2)
-	 *
+	 * 
 	 * @var integer
 	 */
 	var $contributable 	= NULL;
 
 	/**
 	 * text
-	 *
+	 * 
 	 * @var string
 	 */
 	var $customFields 	= NULL;
 
 	/**
 	 * text
-	 *
+	 * 
 	 * @var string
 	 */
 	var $params 		= NULL;
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object &$db JDatabase
 	 * @return     void
 	 */
@@ -105,73 +105,37 @@ class ResourcesType extends JTable
 
 	/**
 	 * Validate data
-	 *
+	 * 
 	 * @return     boolean True if data is valid
 	 */
 	public function check()
 	{
-		$this->type = trim($this->type);
-		if ($this->type == '')
+		if (trim($this->type) == '') 
 		{
 			$this->setError(JText::_('Your resource type must contain text.'));
 			return false;
 		}
-
 		if (!$this->alias)
 		{
 			$this->alias = $this->type;
 		}
 		$this->alias = $this->normalize($this->alias);
-
-		$this->contributable = $this->contributable ?: 0;
-
 		return true;
 	}
 
-	/**
-	 * Returns a reference to a wiki page object
-	 *
-	 * This method must be invoked as:
-	 *     $page = ResourcesType::getRecordInstance($id);
-	 *
-	 * @param      integer $id The record to load
-	 * @return     object
-	 */
-	public static function getRecordInstance($id)
-	{
-		static $instances;
-
-		if (!isset($instances))
-		{
-			$instances = array();
-		}
-
-		if (!isset($instances[$id]))
-		{
-			$db = JFactory::getDBO();
-
-			$tbl = new self($db);
-			$tbl->load($id);
-
-			$instances[$id] = $tbl;
-		}
-
-		return $instances[$id];
-	}
-
 	/**
 	 * Strip disallowed characters and make lowercase
-	 *
+	 * 
 	 * @return     string
 	 */
 	public function normalize($txt)
 	{
-		return preg_replace("/[^a-zA-Z0-9\-_]/", '', strtolower($txt));
+		return preg_replace("/[^a-zA-Z0-9]/", '', strtolower($txt));
 	}
 
 	/**
 	 * Get all the major types
-	 *
+	 * 
 	 * @return     array
 	 */
 	public function getMajorTypes()
@@ -181,18 +145,18 @@ class ResourcesType extends JTable
 
 	/**
 	 * Get a count of all records for a specific category (optional)
-	 *
+	 * 
 	 * @param      array $filters Filters to build query from
 	 * @return     integer
 	 */
 	public function getAllCount($filters=array())
 	{
 		$query = "SELECT count(*) FROM $this->_tbl";
-		if (isset($filters['category']) && $filters['category'])
+		if (isset($filters['category']) && $filters['category']) 
 		{
-			$query .= " WHERE category=" . $this->_db->Quote($filters['category']);
+			$query .= " WHERE category=" . $filters['category'];
 		}
-		else
+		else 
 		{
 			$query .= " WHERE category!=0 ";
 		}
@@ -204,23 +168,23 @@ class ResourcesType extends JTable
 	/**
 	 * Get all records for a specific category (optional)
 	 * Different from the method below in that it adds limit for paging
-	 *
+	 * 
 	 * @param      array $filters Filters to build query from
 	 * @return     array
 	 */
 	public function getAllTypes($filters=array())
 	{
 		$query  = "SELECT * FROM $this->_tbl ";
-		if (isset($filters['category']) && $filters['category'])
+		if (isset($filters['category']) && $filters['category']) 
 		{
-			$query .= "WHERE category=" . $this->_db->Quote($filters['category']) . " ";
+			$query .= "WHERE category=" . $filters['category'] . " ";
 		}
-		else
+		else 
 		{
 			$query .= "WHERE category!=0 ";
 		}
 		$query .= "ORDER BY " . $filters['sort'] . " " . $filters['sort_Dir'] . " ";
-		$query .= "LIMIT " . (int) $filters['start'] . "," . (int) $filters['limit'];
+		$query .= "LIMIT " . $filters['start'] . "," . $filters['limit'];
 
 		$this->_db->setQuery($query);
 		return $this->_db->loadObjectList();
@@ -228,29 +192,29 @@ class ResourcesType extends JTable
 
 	/**
 	 * Get all records for a specific category
-	 *
+	 * 
 	 * @param      integer $cat Category ID
 	 * @return     array
 	 */
 	public function getTypes($cat='0')
 	{
-		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE category=" . $this->_db->Quote($cat) . " ORDER BY type");
+		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE category=" . $cat . " ORDER BY type");
 		return $this->_db->loadObjectList();
 	}
 
 	/**
 	 * Check if a type is being used
-	 *
+	 * 
 	 * @param      integer $id Record ID
 	 * @return     integer
 	 */
 	public function checkUsage($id=NULL)
 	{
-		if (!$id)
+		if (!$id) 
 		{
 			$id = $this->id;
 		}
-		if (!$id)
+		if (!$id) 
 		{
 			return false;
 		}
@@ -259,13 +223,13 @@ class ResourcesType extends JTable
 
 		$r = new ResourcesResource($this->_db);
 
-		$this->_db->setQuery("SELECT count(*) FROM $r->_tbl WHERE type=" . $this->_db->Quote($id) . " OR logical_type=" . $this->_db->Quote($id));
+		$this->_db->setQuery("SELECT count(*) FROM $r->_tbl WHERE type=" . $id . " OR logical_type=" . $id);
 		return $this->_db->loadResult();
 	}
 
 	/**
 	 * Get all the roles associated with a specific type
-	 *
+	 * 
 	 * @param      integer $type_id Type ID
 	 * @return     array
 	 */
@@ -275,27 +239,27 @@ class ResourcesType extends JTable
 		{
 			$type_id = $this->id;
 		}
-
-		if ($type_id === null)
+		
+		if ($type_id === null) 
 		{
 			$this->setError(JText::_('Missing argument'));
 			return false;
 		}
-
+		
 		$type_id = intval($type_id);
-
-		$query = "SELECT r.id, r.title, r.alias
-					FROM `#__author_roles` AS r
-					JOIN `#__author_role_types` AS rt ON r.id=rt.role_id AND rt.type_id=" . $this->_db->Quote($type_id) . "
+		
+		$query = "SELECT r.id, r.title, r.alias 
+					FROM #__author_roles AS r
+					JOIN #__author_role_types AS rt ON r.id=rt.role_id AND rt.type_id=$type_id
 					ORDER BY r.title ASC";
-
+		
 		$this->_db->setQuery($query);
 		return $this->_db->loadObjectList();
 	}
 
 	/**
 	 * Delete a record
-	 *
+	 * 
 	 * @param      integer $oid Record ID
 	 * @return     boolean True on success
 	 */
