@@ -31,14 +31,13 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-$this->baseURL = rtrim(str_replace('/administrator', '', $this->baseURL), '/');
-
-$link = JFactory::getConfig()->get('sef') && JFactory::getApplication()->isAdmin()
-	? '/members/confirm?confirm=' . -$this->confirm
-	: JRoute::_('index.php?option=' . $this->option . '&task=confirm&confirm=' . -$this->confirm);
+$sef = JRoute::_('index.php?option=com_register&task=confirm&confirm='. -$this->confirm);
+if (substr($sef,0,1) == '/') {
+	$sef = substr($sef,1,strlen($sef));
+}
 ?>
 This email is to confirm the email address for the <?php echo $this->sitename; ?> account: <?php echo $this->login; ?>.
 
 Click the following link to confirm your email address and activate your <?php echo $this->sitename; ?> account.
 
-<?php echo $this->baseURL . $link; ?>
\ No newline at end of file
+<?php echo $this->baseURL . $sef; ?>
\ No newline at end of file
