@@ -35,56 +35,107 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Module class for displaying quotes
  */
-class modQuotes extends \Hubzero\Module\Module
+class modQuotes extends JObject
 {
+	/**
+	 * Container for properties
+	 * 
+	 * @var array
+	 */
+	private $attributes = array();
+
+	/**
+	 * Constructor
+	 * 
+	 * @param      object $params JParameter
+	 * @param      object $module Database row
+	 * @return     void
+	 */
+	public function __construct($params, $module)
+	{
+		$this->params = $params;
+		$this->module = $module;
+	}
+
+	/**
+	 * Set a property
+	 * 
+	 * @param      string $property Name of property to set
+	 * @param      mixed  $value    Value to set property to
+	 * @return     void
+	 */
+	public function __set($property, $value)
+	{
+		$this->attributes[$property] = $value;
+	}
+
+	/**
+	 * Get a property
+	 * 
+	 * @param      string $property Name of property to retrieve
+	 * @return     mixed
+	 */
+	public function __get($property)
+	{
+		if (isset($this->attributes[$property])) 
+		{
+			return $this->attributes[$property];
+		}
+	}
+
+	/**
+	 * Check if a property is set
+	 * 
+	 * @param      string $property Property to check
+	 * @return     boolean True if set
+	 */
+	public function __isset($property)
+	{
+		return isset($this->_attributes[$property]);
+	}
+
 	/**
 	 * Get module contents
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function run()
 	{
-		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_feedback' . DS . 'tables' . DS . 'quotes.php');
+		require_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_feedback' . DS . 'tables' . DS . 'selectedquotes.php');
 
 		$this->database = JFactory::getDBO();
 
 		//Get the admin configured settings
-		$this->filters = array(
-			'limit'         => trim($this->params->get('maxquotes')),
-			'id'            => JRequest::getInt('quoteid', 0),
-			'notable_quote' => 1
-		);
+		$filters = array();
+		$filters['limit'] = trim($this->params->get('maxquotes'));
+		$filters['id'] = JRequest::getInt('quoteid', 0);
+		$filters['notable_quotes'] = 1;
+
+		$this->filters = $filters;
 
 		// Get quotes
-		$sq = new FeedbackQuotes($this->database);
-		$this->quotes = $sq->find('list', $this->filters);
-
-		$feedbackConfig = JComponentHelper::getParams('com_feedback');
-		$this->path = trim($feedbackConfig->get('uploadpath', '/site/quotes'), DS) . DS;
+		$sq = new SelectedQuotes($this->database);
+		$this->quotes = $sq->getResults($filters);
 
 		require(JModuleHelper::getLayoutPath($this->module->module));
 	}
 
 	/**
 	 * Display module content
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function display()
 	{
-		// Push the module CSS to the template
-		$this->css()
-		     ->js();
+		$juser =& JFactory::getUser();
 
-		$debug = (defined('JDEBUG') && JDEBUG ? true : false);
-
-		if (!$debug && intval($this->params->get('cache', 0)))
+		if (!$juser->get('guest') && intval($this->params->get('cache', 0)))
 		{
-			$cache = JFactory::getCache('callback');
+			$cache =& JFactory::getCache('callback');
 			$cache->setCaching(1);
 			$cache->setLifeTime(intval($this->params->get('cache_time', 15)));
 			$cache->call(array($this, 'run'));
-			echo '<!-- cached ' . JFactory::getDate() . ' -->';
+			echo '<!-- cached ' . date('Y-m-d H:i:s', time()) . ' -->';
 			return;
 		}
 
